( cd usr/lib ; rm -rf libstdc++.so.6 )
( cd usr/lib ; ln -sf libstdc++.so.6.0.9 libstdc++.so.6 )
( cd usr/powerpc-slackware-linux/lib ; rm -rf libstdc++.so.5 )
( cd usr/powerpc-slackware-linux/lib ; ln -sf libstdc++.so.5.0.7 libstdc++.so.5 )

